# FK Library
[![license](https://img.shields.io/badge/python-3.6-brightgreen.svg)](LICENSE)
[![license](https://img.shields.io/badge/version-1.0.0-orange.svg)](LICENSE)
[![license](https://img.shields.io/badge/size-lightweight-blue.svg)](LICENSE)
## Introduction
This is a lightweight library written by python3 that covers the following features. It is now the first version and continues to expand.
- Basic Data Structure Operation
- String Process
- Math Calculate
- Time Calculate
- Parallel Operation
- File I/O
- Internet I/O
- Model Wrapper

## Requirements
- [Numpy](http://www.numpy.org/)
- [Python 3](https://www.python.org/)

## PyPI
```bash
pip3 install fkl
```
## More Details
Use ```help```to find more detailed usage of functions and classes.
